# Generated by Django 2.2.1 on 2020-04-06 06:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('smpl_message_log', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='messagelog',
            options={'default_permissions': (), 'ordering': ('-created',)},
        ),
    ]
